Module embedding

Module embedding 

Embedding provider traits and implementations.

Structs

CandleEmbeddingModelFiles
Local file paths needed to load a Candle embedding model.
CandleEmbeddingModelSpec
Model specification used to download a sentence embedding model from Hugging Face.
CandleEmbeddingProvider
Local embedding provider backed by Candle and a BERT-style sentence model.
OpenAiCompatibleEmbeddingProvider
Embedding provider for OpenAI-compatible /embeddings HTTP APIs.

Traits

EmbeddingProvider
Trait implemented by embedding backends that can turn raw texts into vectors.