EmbeddingProvider

Trait EmbeddingProvider 

pub trait EmbeddingProvider {
    // Required method
    fn embed(&self, records: &[InputRecord]) -> PopsamResult<Vec<EmbeddedText>>;
}
Trait implemented by embedding backends that can turn raw texts into vectors.

Required Methods

fn embed(&self, records: &[InputRecord]) -> PopsamResult<Vec<EmbeddedText>>

Embeds a batch of records and returns the corresponding vectors.

Implementors