Module model

Module model 

Serializable data models used by the public API.

Structs

CandidateBestResult
Best round result reached by a candidate during the full election.
CandidateRoundVotes
Vote totals for a candidate in a single round.
ElectionResult
Result of running the elimination algorithm on a collection of embeddings.
EmbeddedText
Record returned by an embedding provider or included in an election result.
EmbeddedTextInput
Input record with a caller-provided embedding vector.
InputRecord
Raw input text identified by a caller-provided ID.
RoundSummary
Summary of a reported round among the final k candidates.