pub trait EmbeddingProvider {
// Required method
fn embed(&self, records: &[InputRecord]) -> PopsamResult<Vec<EmbeddedText>>;
}Expand description
Trait implemented by embedding backends that can turn raw texts into vectors.
Required Methods
Sourcefn embed(&self, records: &[InputRecord]) -> PopsamResult<Vec<EmbeddedText>>
fn embed(&self, records: &[InputRecord]) -> PopsamResult<Vec<EmbeddedText>>
Embeds a batch of records and returns the corresponding vectors.