Serializable data models used by the public API.
Structs
- Candidate
Best Result - Best round result reached by a candidate during the full election.
- Candidate
Round Votes - Vote totals for a candidate in a single round.
- Election
Result - Result of running the elimination algorithm on a collection of embeddings.
- Embedded
Text - Record returned by an embedding provider or included in an election result.
- Embedded
Text Input - Input record with a caller-provided embedding vector.
- Input
Record - Raw input text identified by a caller-provided ID.
- Round
Summary - Summary of a reported round among the final
kcandidates.